@@ -195,7 +195,9 @@ sub pre_gen_list {
     my @keeplist = ();
     my $numtasks = 0;
     my $level    = 0;
-    my @joblist = gen_list( \@motcount, $level, \@keeplist, $half, \$numtasks );
+    my @joblist;
+    # my @joblist = gen_list( \@motcount, $level, \@keeplist, $half, \$numtasks );
+    gen_list( \@joblist, \@motcount, $level, \@keeplist, $half, \$numtasks );
     return @joblist;
 }
 
@@ -206,8 +208,9 @@ Subroutine to generate the input list for enumeration
 =cut
 
 sub gen_list {
-    my ( $motcount, $level, $keeplist, $half, $numtasks ) = @_;
-    my @joblist;
+    # my ( $motcount, $level, $keeplist, $half, $numtasks ) = @_;
+    my (  $aref_joblist, $motcount, $level, $keeplist, $half, $numtasks ) = @_;
+    # my @joblist;
     if ( $level == $half ) {
         my $start = '';
         if ( scalar(@$keeplist) > 0 ) {
@@ -218,7 +221,8 @@ sub gen_list {
         for ( my $aa = 0 ; $aa < $$motcount[$level] ; $aa++ ) {
 
             #print OUTFILE "$start\_$aa ";
-            push( @joblist, "$start\_$aa " );
+            # push( @joblist, "$start\_$aa " );
+            push( @{$aref_joblist}, "$start\_$aa " );
             $$numtasks++;
         }
     }
@@ -227,11 +231,12 @@ sub gen_list {
         push( @templist, 0 );
         for ( my $aa = 0 ; $aa < $$motcount[$level] ; $aa++ ) {
             $templist[-1] = $aa;
-            gen_list( \@$motcount, $level + 1, \@templist, $half, \$$numtasks );
+            # gen_list( \@$motcount, $level + 1, \@templist, $half, \$$numtasks );
+             gen_list( $aref_joblist, \@$motcount, $level + 1, \@templist, $half, \$$numtasks );
         }
     }
     else { }
-    return @joblist;
+    # return @joblist;
 }
 
 =head2 enumerate
